<!-- markdownlint-disable -->

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/export.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `export`





---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/export.py#L26"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `get_list_slug`

```python
get_list_slug(str_list)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/export.py#L39"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `convert_pd_to_gdf`

```python
convert_pd_to_gdf(pd_df)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/export.py#L67"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `OutFileWriter`




<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/export.py#L69"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `__init__`

```python
__init__(region_list, primary_name, feature_list, data_dir, out_format)
```









